==> 29wptouch-2.8.12.zip: wptouch/themes/core29/core-header.php <==
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" <?php language_attributes(); ?>>
<head profile="http://gmpg.org/xfn/11">
	<meta name="generator" content="WordPress <?php bloginfo('version'); ?>" />
	<meta http-equiv="Content-Type" content="<?php bloginfo('html_type'); ?>; charset=<?php bloginfo('charset'); ?>" />
	<?php if ( bnc_is_zoom_enabled() ) { ?>
		<meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=2.0, user-scalable=yes" />
	<?php } else { ?>
		<meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=no" />
	<?php } ?>
	<title><?php if ( is_home() ) { ?><?php bloginfo('name'); ?><?php } ?><?php if ( is_front_page() ) { ?><?php } ?><?php if ( is_search() ) { ?>「<?php the_search_query(); ?>」の検索結果【<?php bloginfo('name'); ?>】<?php } ?>
<?php if ( is_author() ) { ?><?php bloginfo('name'); ?>【Author Archives】<?php } ?>
<?php if ( is_single() ) { ?><?php wp_title(''); ?>【<?php $cat = get_the_category(); $cat = $cat[0]; { echo $cat->cat_name; } ?>】<?php } ?>
<?php if ( is_page() ) { ?><?php bloginfo('name'); ?>　<?php wp_title(''); ?><?php } ?>
<?php if ( is_category() ) { ?><?php single_cat_title(); ?>の記事一覧【<?php bloginfo('name'); ?>】<?php } ?>
<?php if ( is_month() ) { ?><?php bloginfo('name'); ?>　<?php the_time('F'); ?>の記事<?php } ?>
<?php if ( is_404() ) { ?><?php bloginfo('name'); ?>　ページが見つかりません<?php } ?>
<?php if (function_exists('is_tag')) { if ( is_tag() ) { ?><?php single_tag_title("", true); ?>【<?php bloginfo('name'); ?>】<?php ; } } ?>
</title>
	<link rel="alternate" type="application/rss+xml" title="<?php bloginfo('name'); ?> RSS Feed" href="<?php bloginfo('rss2_url'); ?>" />
	<link <?php if (bnc_is_flat_icon_enabled()) { echo 'rel="apple-touch-icon-precomposed"'; } else { echo 'rel="apple-touch-icon"';} ?> href="<?php echo bnc_get_title_image(); ?>" />
	<link rel="stylesheet" href="<?php bloginfo('stylesheet_directory'); ?>/style.css" type="text/css" media="screen" />


<?php wptouch_core_header_styles(); wptouch_core_header_enqueue(); ?>

<?php if (bnc_is_gigpress_enabled() && function_exists( 'gigpress_shows' )) { ?>
		<link rel="stylesheet" href="<?php echo compat_get_plugin_url( 'wptouch' ); ?>/themes/core/core-css/gigpress.css" type="text/css" media="screen" />
		<?php } ?>
	<?php if (!is_single()) { ?>
		<script type="text/javascript">
			// Hides the addressbar on non-post pages
			function hideURLbar() { window.scrollTo(0,1); }
			addEventListener('load', function() { setTimeout(hideURLbar, 0); }, false );
		</script>
<?php } ?>

<!-- java -->
<script src="<?php bloginfo('url'); ?>/wp-content/plugins/wptouch/themes/core29/jquery1-63.js" charset="utf-8"></script>
<script src="<?php bloginfo('url'); ?>/wp-content/plugins/wptouch/themes/core29/st-week.js" charset="utf-8"></script>

<!--▼ GoogleAnalyticsトラッキングコード ▼-->

<!--▲ GoogleAnalyticsトラッキングコード ▲-->
</head>
<?php flush();

==> 29wptouch2.9.8.zip: wptouch/themes/core29/core-header.php <==
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" <?php language_attributes(); ?>>
<head profile="http://gmpg.org/xfn/11">
	<meta name="generator" content="WordPress <?php bloginfo('version'); ?>" />
	<meta http-equiv="Content-Type" content="<?php bloginfo('html_type'); ?>; charset=<?php bloginfo('charset'); ?>" />
	<?php if ( bnc_is_zoom_enabled() ) { ?>
		<meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=2.0, user-scalable=yes" />
	<?php } else { ?>
		<meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=no" />
	<?php } ?>
	<title><?php if ( is_home() ) { ?><?php bloginfo('name'); ?><?php } ?><?php if ( is_front_page() ) { ?><?php } ?><?php if ( is_search() ) { ?>「<?php the_search_query(); ?>」の検索結果【<?php bloginfo('name'); ?>】<?php } ?>
<?php if ( is_author() ) { ?><?php bloginfo('name'); ?>【Author Archives】<?php } ?>
<?php if ( is_single() ) { ?><?php wp_title(''); ?>【<?php $cat = get_the_category(); $cat = $cat[0]; { echo $cat->cat_name; } ?>】<?php } ?>
<?php if ( is_page() ) { ?><?php bloginfo('name'); ?>　<?php wp_title(''); ?><?php } ?>
<?php if ( is_category() ) { ?><?php single_cat_title(); ?>の記事一覧【<?php bloginfo('name'); ?>】<?php } ?>
<?php if ( is_month() ) { ?><?php bloginfo('name'); ?>　<?php the_time('F'); ?>の記事<?php } ?>
<?php if ( is_404() ) { ?><?php bloginfo('name'); ?>　ページが見つかりません<?php } ?>
<?php if (function_exists('is_tag')) { if ( is_tag() ) { ?><?php single_tag_title("", true); ?>【<?php bloginfo('name'); ?>】<?php ; } } ?>
</title>
	<link rel="alternate" type="application/rss+xml" title="<?php bloginfo('name'); ?> RSS Feed" href="<?php bloginfo('rss2_url'); ?>" />
	<link <?php if (bnc_is_flat_icon_enabled()) { echo 'rel="apple-touch-icon-precomposed"'; } else { echo 'rel="apple-touch-icon"';} ?> href="<?php echo bnc_get_title_image(); ?>" />
	<link rel="stylesheet" href="<?php bloginfo('stylesheet_directory'); ?>/style.css" type="text/css" media="screen" />


<?php wptouch_core_header_styles(); wptouch_core_header_enqueue(); ?>

<?php if (bnc_is_gigpress_enabled() && function_exists( 'gigpress_shows' )) { ?>
		<link rel="stylesheet" href="<?php echo compat_get_plugin_url( 'wptouch' ); ?>/themes/core/core-css/gigpress.css" type="text/css" media="screen" />
		<?php } ?>
	<?php if (!is_single()) { ?>
		<script type="text/javascript">
			// Hides the addressbar on non-post pages
			function hideURLbar() { window.scrollTo(0,1); }
			addEventListener('load', function() { setTimeout(hideURLbar, 0); }, false );
		</script>
<?php } ?>

<!-- java -->
<script src="<?php bloginfo('url'); ?>/wp-content/plugins/wptouch/themes/core29/jquery1-63.js" charset="utf-8"></script>
<script src="<?php bloginfo('url'); ?>/wp-content/plugins/wptouch/themes/core29/st-week.js" charset="utf-8"></script>

<!-- jQuery.jsの読み込み -->
<script type="text/javascript" src="//ajax.googleapis.com/ajax/libs/jquery/1.3.2/jquery.min.js"></script>

<!-- スムーズスクロール部分の記述 -->
<script>
$(function(){
   // #で始まるアンカーをクリックした場合に処理
   $('a[href^=#]').click(function() {
      // スクロールの速度
      var speed = 400; // ミリ秒
      // アンカーの値取得
      var href= $(this).attr("href");
      // 移動先を取得
      var target = $(href == "#" || href == "" ? 'html' : href);
      // 移動先を数値で取得
      var position = target.offset().top;
      // スムーススクロール
      $('body,html').animate({scrollTop:position}, speed, 'swing');
      return false;
   });
});
</script>

<!--▼ GoogleAnalyticsトラッキングコード ▼-->

<!--▲ GoogleAnalyticsトラッキングコード ▲-->
</head>
<?php flush();
